"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const core_1 = require("@oclif/core");
const color_1 = require("@heroku-cli/color");
const core_2 = require("@salesforce/core");
const functions_core_1 = require("@heroku/functions-core");
const base_1 = require("../../lib/base");
core_2.Messages.importMessagesDirectory(__dirname);
const messages = core_2.Messages.loadMessages('@salesforce/plugin-functions', 'generate.project');
class GenerateProject extends base_1.default {
    async run() {
        var _a;
        const { flags } = await this.parse(GenerateProject);
        const pnName = (_a = flags['project-name']) !== null && _a !== void 0 ? _a : flags.name;
        if (!pnName) {
            throw new core_1.Errors.CLIError(`Missing required flag:
       -n, --project-name PROJECT-NAME  ${color_1.default.dim('Name of the generated project.')}
       See more help with --help`);
        }
        if (flags.name) {
            this.warn(messages.getMessage('flags.name.deprecation'));
        }
        try {
            await functions_core_1.generateProject(pnName);
        }
        catch (err) {
            this.error(err.message);
        }
    }
}
exports.default = GenerateProject;
GenerateProject.examples = messages.getMessages('examples');
GenerateProject.flags = {
    'project-name': core_1.Flags.string({
        exclusive: ['name'],
        description: messages.getMessage('flags.project-name.summary'),
        char: 'n',
    }),
    name: core_1.Flags.string({
        exclusive: ['project-name'],
        description: messages.getMessage('flags.project-name.summary'),
        char: 'n',
        hidden: true,
    }),
};
