/// <reference types="node" />
import { URL } from 'url';
import { Errors } from '@oclif/core';
import { AxiosError, AxiosRequestConfig, AxiosResponse } from 'axios';
interface APIClientConfig {
    auth: string;
    apiUrl: URL;
}
export interface HerokuAPIErrorOptions {
    resource?: string;
    app?: {
        id: string;
        name: string;
    };
    id?: string;
    message?: string;
    url?: string;
}
export declare class APIError extends Errors.CLIError {
    http: AxiosError;
    body: HerokuAPIErrorOptions;
    constructor(httpError: AxiosError);
}
export default class APIClient {
    private axios;
    private auth;
    private apiUrl;
    constructor(options: APIClientConfig);
    request<T>(url: string, options?: AxiosRequestConfig): Promise<AxiosResponse<T>>;
    get<T>(url: string, options?: AxiosRequestConfig): Promise<AxiosResponse<T>>;
    post<T>(url: string, options?: AxiosRequestConfig): Promise<AxiosResponse<T>>;
    put<T>(url: string, options?: AxiosRequestConfig): Promise<AxiosResponse<T>>;
    patch<T>(url: string, options?: AxiosRequestConfig): Promise<AxiosResponse<T>>;
    delete<T>(url: string, options?: AxiosRequestConfig): Promise<AxiosResponse<T>>;
}
export declare function herokuClientApiUrl(): URL;
export {};
